from setuptools import setup, find_packages

setup(
    name='mycoollibrary',
    version='0.1',
    packages=find_packages(),
    install_requires=[
        # Нет зависимостей в данном случае
    ],
)
